## Acknowledgements

- The iPhone teleoperation code and app is develeped by [Ruihan Zhao](https://philipzrh.com/)
- We use [mediapipe](https://developers.google.com/mediapipe) for human keypoint detection
- The oculus code and transformations have been adapted from [DROID](https://github.com/AlexanderKhazatsky/R2D2/tree/main)
- We use [RoboMimic](https://robomimic.github.io/docs/introduction/overview.html) for imitation learning